@@ -582,7 +582,7 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
         }
 
         // Octet Byte[1] bits[7-0] - True/False tags
-        if (tagstring.length() >= 4) { 
+        if (tagstring.length() >= 4) {
           // bits[3-0]
           uint8_t data = getBinaryData(tagstring[3]);
 
@@ -609,12 +609,15 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
             doc["track"] = true;
             jsondata["track"] = doc["track"];
           }
-          // bits[7-4]
-          data = getBinaryData(tagstring[2]);
+        }
 
-          if (((data >> 0) & 0x01) == 1) { // Encrypted device data
+        // Octet Byte[2] - Encryption Model
+        if (tagstring.length() >= 6) {
+          int encrmode = strtol(tagstring.substr(4, 2).c_str(), NULL, 16);
+          DEBUG_PRINT("encrmode: %d\n", encrmode);
+          if (encrmode > 0) {
             doc.add("encr");
-            doc["encr"] = true;
+            doc["encr"] = encrmode;
             jsondata["encr"] = doc["encr"];
           }
         }
@@ -796,8 +799,22 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
             }
 
             std::string value(src + decoder[2].as<int>(), decoder[3].as<int>());
-            jsondata[sanitizeJsonKey(kv.key().c_str())] = value;
-            success = i_main;
+
+            /* Lookup table */
+            if (prop.containsKey("lookup")) {
+              JsonArray lookup = prop["lookup"];
+              for (unsigned int i = 0; i < lookup.size(); i += 2) {
+                if (lookup[i].as<std::string>() == value) {
+                  value = lookup[i + 1].as<std::string>();
+                  jsondata[sanitizeJsonKey(kv.key().c_str())] = value;
+                  success = i_main;
+                  break;
+                }
+              }
+            } else {
+              jsondata[sanitizeJsonKey(kv.key().c_str())] = value;
+              success = i_main;
+            }
           } else if (strstr((const char*)decoder[0], "mac_from_hex_data") != nullptr) {
             const char* src = svc_data;
             if (strstr((const char*)decoder[1], MFG_DATA)) {
@@ -813,6 +830,7 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
               char* reverse_mac_string = (char*)malloc(strlen(mac_string) + 1);
               reverse_hex_data(mac_string, reverse_mac_string, 12);
               value = reverse_mac_string;
+              free(reverse_mac_string);
             }
 
             // upper case MAC
