@@ -67,13 +67,17 @@ public:
     IBT4XS,
     IBT6XS_SOLIS,
     MIBAND,
-    XMTZC04HM,
-    XMTZC05HM,
+    XMTZC04HMKG,
+    XMTZC04HMLB,
+    XMTZC05HMKG,
+    XMTZC05HMLB,
     TPMS,
     KKM_K6P,
     KKM_K9,
     LYWSD03MMC_ATC,
     LYWSD03MMC_PVVX,
+    LYWSD03MMC_PVVX_DECR,
+    LYWSD03MMC_PVVX_ENCR,
     CGPR1,
     THERMOBEACON,
     H5055,
@@ -81,6 +85,7 @@ public:
     H5074,
     H5102,
     H5106,
+    H5179,
     HHCCJCY10,
     MUE4094RT,
     MOKOBEACON,
@@ -108,10 +113,13 @@ public:
     BPARASITE,
     BWBSDOO,
     BM2,
+    BM6,
     RDL52832,
     ABN03,
+    ABN07,
     ABTEMP,
     AMPHIRO,
+    ORALB_BT,
     PH10,
     TPTH,
     MOPEKA,
@@ -128,7 +136,11 @@ public:
     APPLE_CONTAT,
     SERVICE_DATA,
     SBBT_002C,
-    SBBT_002C_ENC,
+    SBBT_002C_ENCR,
+    SBDW_002C,
+    SBDW_002C_ENCR,
+    SBMO_003Z,
+    SBMO_003Z_ENCR,
     BLE_ID_MAX
   };
 
