@@ -32,6 +32,7 @@
 #include "devices/H5074_json.h"
 #include "devices/H5102_json.h"
 #include "devices/H5106_json.h"
+#include "devices/H5179_json.h"
 #include "devices/HHCCJCY10_json.h"
 #include "devices/HHCCJCY01HHCC_json.h"
 #include "devices/HHCCPOT002_json.h"
@@ -42,11 +43,16 @@
 #include "devices/JQJCY01YM_json.h"
 #include "devices/LYWSD02_json.h"
 #include "devices/LYWSD03MMC_json.h"
+#include "devices/LYWSD03MMC_ENCR_json.h"
 #include "devices/LYWSDCGQ_json.h"
 #include "devices/MBXPRO_json.h"
 #include "devices/MS_CDP_json.h"
 #include "devices/MUE4094RT_json.h"
 #include "devices/Miband_json.h"
+#include "devices/XMTZC04HMKG_json.h"
+#include "devices/XMTZC04HMLB_json.h"
+#include "devices/XMTZC05HMKG_json.h"
+#include "devices/XMTZC05HMLB_json.h"
 #include "devices/Mokobeacon_json.h"
 #include "devices/RDL52832_json.h"
 #include "devices/RuuviTag_RAWv1_json.h"
@@ -65,11 +71,11 @@
 #include "devices/KKM_K6P_json.h"
 #include "devices/KKM_K9_json.h"
 #include "devices/ThermoBeacon_json.h"
-#include "devices/XMTZC04HM_json.h"
-#include "devices/XMTZC05HM_json.h"
 #include "devices/ABN03_json.h"
+#include "devices/ABN07_json.h"
 #include "devices/ABTemp_json.h"
 #include "devices/Amphiro_json.h"
+#include "devices/OralB_json.h"
 #include "devices/PH10_json.h"
 #include "devices/TPTH_json.h"
 #include "devices/Mopeka_json.h"
@@ -84,12 +90,17 @@
 #include "devices/BPARASITE_json.h"
 #include "devices/BWBSDOO_json.h"
 #include "devices/BM2_json.h"
+#include "devices/BM6_json.h"
 #include "devices/JHT_F525_json.h"
 #include "devices/iBeacon_json.h"
 #include "devices/APPLE_json.h"
 #include "devices/ServiceData_json.h"
 #include "devices/SBBT_002C_json.h"
-#include "devices/SBBT_002C_encrypted_json.h"
+#include "devices/SBBT_002C_ENCR_json.h"
+#include "devices/SBDW_002C_json.h"
+#include "devices/SBDW_002C_ENCR_json.h"
+#include "devices/SBMO_003Z_json.h"
+#include "devices/SBMO_003Z_ENCR_json.h"
 
 
 const char* _devices[][2] = {
@@ -114,13 +125,17 @@ const char* _devices[][2] = {
     {_IBT_4XS_json, _IBT_4XS_json_props},
     {_IBT_6XS_SOLIS6_json, _IBT_6XS_SOLIS6_json_props},
     {_Miband_json, _Miband_json_props},
-    {_XMTZC04HM_json, _XMTZC04HM_json_props},
-    {_XMTZC05HM_json, _XMTZC05HM_json_props},
+    {_XMTZC04HMKG_json, _XMTZC04HMKG_json_props},
+    {_XMTZC04HMLB_json, _XMTZC04HMLB_json_props},
+    {_XMTZC05HMKG_json, _XMTZC05HMKG_json_props},
+    {_XMTZC05HMLB_json, _XMTZC05HMLB_json_props},
     {_TPMS_json, _TPMS_json_props},
     {_KKM_K6P_json, _KKM_K6P_json_props},
     {_KKM_K9_json, _KKM_K9_json_props},
     {_LYWSD03MMC_json_ATC, _LYWSD03MMC_json_props},
     {_LYWSD03MMC_json_PVVX, _LYWSD03MMC_json_props},
+    {_LYWSD03MMC_json_PVVX_DECR, _LYWSD03MMC_json_props},
+    {_LYWSD03MMC_ENCR_json_PVVX, _LYWSD03MMC_ENCR_json_props},
     {_CGPR1_json, _CGPR1_json_props},
     {_ThermoBeacon_json, _ThermoBeacon_json_props},
     {_H5055_json, _H5055_json_props},
@@ -128,6 +143,7 @@ const char* _devices[][2] = {
     {_H5074_json, _H5074_json_props},
     {_H5102_json, _H5102_json_props},
     {_H5106_json, _H5106_json_props},
+    {_H5179_json, _H5179_json_props},
     {_HHCCJCY10_json, _HHCCJCY10_json_props},
     {_MUE4094RT_json, _MUE4094RT_json_props},
     {_Mokobeacon_json, _Mokobeacon_json_props},
@@ -155,10 +171,13 @@ const char* _devices[][2] = {
     {_BPARASITE_json, _BPARASITE_json_props},
     {_BWBSDOO_json, _BWBSDOO_json_props},
     {_BM2_json, _BM2_json_props},
+    {_BM6_json, _BM6_json_props},
     {_RDL52832_json, _RDL52832_json_props},
     {_ABN03_json, _ABN03_json_props},
+    {_ABN07_json, _ABN07_json_props},
     {_ABTemp_json, _ABTemp_json_props},
     {_AMPHIRO_json, _AMPHIRO_json_props},
+    {_OralB_json, _OralB_json_props},
     {_PH10_json, _PH10_json_props},
     {_TPTH_json, _TPTH_json_props},
     {_Mopeka_json, _Mopeka_json_props},
@@ -175,5 +194,9 @@ const char* _devices[][2] = {
     {_APPLE_json_at, _APPLE_json_props},
     {_ServiceData_json, _ServiceData_json_props},
     {_SBBT_002C_json, _SBBT_002C_json_props},
-    {_SBBT_002C_encrypted_json, _SBBT_002C_encrypted_json_props},
+    {_SBBT_002C_ENCR_json, _SBBT_002C_ENCR_json_props},
+    {_SBDW_002C_json, _SBDW_002C_json_props},
+    {_SBDW_002C_ENCR_json, _SBDW_002C_ENCR_json_props},
+    {_SBMO_003Z_json, _SBMO_003Z_json_props},
+    {_SBMO_003Z_ENCR_json, _SBMO_003Z_ENCR_json_props},
 };
